define('dojo/nls/pmbdijit_de',{
'dijit/nls/loading':{"loadingState":"Wird geladen...","errorState":"Es ist ein Fehler aufgetreten.","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"Der eingegebene Wert ist ungültig. ","missingMessage":"Dieser Wert ist erforderlich.","rangeMessage":"Dieser Wert liegt außerhalb des gültigen Bereichs. ","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"·","list":";","percentSign":"%","minusSign":"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000 Bio","currencySpacing-afterCurrency-insertBetween":" ","nan":"NaN","plusSign":"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"#,##0.00 ¤","perMille":"‰","group":".","percentFormat":"#,##0 %","decimalFormat-long":"000 Billionen","decimalFormat":"#,##0.###","decimal":",","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"OK","buttonCancel":"Abbrechen","buttonSave":"Speichern","itemClose":"Schließen","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"Fett","copy":"Kopieren","cut":"Ausschneiden","delete":"Löschen","indent":"Einrücken","insertHorizontalRule":"Horizontaler Strich","insertOrderedList":"Nummerierung","insertUnorderedList":"Aufzählungszeichen","italic":"Kursiv","justifyCenter":"Zentriert","justifyFull":"Blocksatz","justifyLeft":"Linksbündig","justifyRight":"Rechtsbündig","outdent":"Ausrücken","paste":"Einfügen","redo":"Wiederholen","removeFormat":"Formatierung entfernen","selectAll":"Alles auswählen","strikethrough":"Durchgestrichen","subscript":"Tiefgestellt","superscript":"Hochgestellt","underline":"Unterstrichen","undo":"Rückgängig","unlink":"Link entfernen","createLink":"Link erstellen","toggleDir":"Richtung wechseln","insertImage":"Grafik einfügen","insertTable":"Tabelle einfügen/bearbeiten","toggleTableBorder":"Tabellenumrandung ein-/ausschalten","deleteTable":"Tabelle löschen","tableProp":"Tabelleneigenschaft","htmlToggle":"HTML-Quelltext","foreColor":"Vordergrundfarbe","hiliteColor":"Hintergrundfarbe","plainFormatBlock":"Absatzstil","formatBlock":"Absatzstil","fontSize":"Schriftgröße","fontName":"Schriftartname","tabIndent":"Registerkarteneinrückung","fullScreen":"Gesamtanzeige","viewSource":"HTML-Quelle","print":"Drucken","newPage":"Neue Seite","systemShortcut":"Die Aktion \"${0}\" ist nur über einen Direktaufruf in Ihrem Browser verfügbar. Verwenden Sie ${1}.","ctrlKey":"Strg+${0}","appleKey":"⌘${0}","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"Vorherige Auswahl","nextMessage":"Weitere Auswahlmöglichkeiten","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"XXS","2":"XS","3":"S","4":"M","5":"L","6":"XL","7":"XXL","fontSize":"Größe","fontName":"Schriftart","formatBlock":"Format","serif":"Serife","sans-serif":"Serifenlos","monospace":"Monospaceschrift","cursive":"Kursiv","fantasy":"Fantasie","noFormat":"Keine Angabe","p":"Absatz","h1":"Überschrift","h2":"Unterüberschrift","h3":"Unterunterüberschrift","pre":"Vorformatiert","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"Umgekehrtes Ausrufezeichen","cent":"Cent-Zeichen","pound":"Nummernzeichen","curren":"Währungssymbol","yen":"Yen-Zeichen\nYuan-Zeichen","brvbar":"Unterbrochener Balken\nUnterbrochener vertikaler Balken","sect":"Abschnittszeichen","uml":"Trema\nPünktchen oben","copy":"Copyrightzeichen","ordf":"Weibliches Ordinalzeichen","laquo":"Doppelte, winklige Anführungszeichen, die nach links weisenlinke französische Anführungszeichen","not":"Nicht-Zeichen","shy":"Veränderlicher Silbentrennstrich\nWeicher Bindestrich","reg":"Registrierte Handelsmarke\nRegistriertes Markenzeichen","macr":"Makron\nLängestrich\nÜberstrich\nKurzer Überstrich über einem Buchstaben","deg":"Gradzeichen","plusmn":"Plus-Minus-Zeichen\nPlus-oder-Minus-Zeichen","sup2":"Hochgestellte Zwei\nHoch 2\nZum Quadrat","sup3":"Hochgestellte Drei\nHoch 3\nKubik","acute":"Akut\nAkutzeichen","micro":"Micro-Zeichen","para":"Pilcrow-Zeichen\nAbsatzzeichen","middot":"Multiplikationszeichen\nGeorgisches Komma\nGriechisches Multiplikationszeichen","cedil":"Cedille\nC mit Häkchen","sup1":"Hochgestellte Eins\nHoch 1","ordm":"Männliches Ordinalzeichen","raquo":"Doppelte, winklige Anführungszeichen, die nach rechts weisen\nRechtes französisches Anführungszeichen","frac14":"Bruch 1 durch 4\nEin Viertel","frac12":"Bruch 1 durch 2\nEinhalb","frac34":"Bruch 3 durch 4\nDreiviertel","iquest":"Umgekehrtes Fragezeichen\nFragezeichen auf dem Kopf","Agrave":"Großes A mit Gravis\nGroßbuchstabe A mit Gravis","Aacute":"Großbuchstabe A mit Akut","Acirc":"Großbuchstabe A mit Zirkumflex","Atilde":"Großbuchstabe A mit Tilde","Auml":"Großbuchstabe A mit Trema","Aring":"Großes A mit Ring darüber\nLateinischer Großbuchstabe A mit Ring darüber","AElig":"Großes AE\nLigatur aus Großbuchstaben A und E","Ccedil":"Großbuchstabe C mit Cedilla","Egrave":"Großbuchstabe E mit Gravis","Eacute":"Großbuchstabe E mit Akut","Ecirc":"Großbuchstabe E mit Zirkumflex","Euml":"Großbuchstabe E mit Trema","Igrave":"Großbuchstabe I mit Gravis","Iacute":"Großbuchstabe I mit Akut","Icirc":"Großbuchstabe I mit Zirkumflex","Iuml":"Großbuchstabe I mit Trema","ETH":"Großes ETH","Ntilde":"Großbuchstabe N mit Tilde","Ograve":"Großbuchstabe O mit Gravis","Oacute":"Großbuchstabe O mit Akut","Ocirc":"Großbuchstabe O mit Zirkumflex","Otilde":"Lateinischer Großbuchstabe O mit Tilde","Ouml":"Lateinischer Großbuchstabe O mit Trema","times":"Multiplikationszeichen","Oslash":"Großes O mit Schrägstrich\nGroßer dänisch-norwegischer Umlaut ö","Ugrave":"Großbuchstabe U mit Gravis","Uacute":"Großbuchstabe U mit Akut","Ucirc":"Großbuchstabe U mit Zirkumflex","Uuml":"Großbuchstabe U mit Trema","Yacute":"Großbuchstabe Y mit Akut","THORN":"Großes THORN","szlig":"Scharfes s\nEsszett","agrave":"Kleines a mit Gravis\nKleinbuchstabe a mit Gravis","aacute":"Kleinbuchstabe a mit Aktut","acirc":"Kleinbuchstabe a mit Zirkumflex","atilde":"Kleinbuchstabe a mit Tilde","auml":"Kleinbuchstabe a mit Trema","aring":"Kleines a mit Ring darüber\nKleinbuchstabe a mit Ring","aelig":"Kleines ae\nLigatur aus Kleinbuchstaben a und e","ccedil":"Kleinbuchstabe c mit Cedilla","egrave":"Kleinbuchstabe e mit Gravis","eacute":"Kleinbuchstabe e mit Aktut","ecirc":"Kleinbuchstabe e mit Zirkumflex","euml":"Kleinbuchstabe e mit Trema","igrave":"Kleinbuchstabe i mit Gravis","iacute":"Kleinbuchstabe i mit Aktut","icirc":"Kleinbuchstabe i mit Zirkumflex","iuml":"Kleinbuchstabe i mit Trema","eth":"Kleines eth","ntilde":"Kleinbuchstabe n mit Tilde","ograve":"Kleinbuchstabe o mit Gravis","oacute":"Kleinbuchstabe o mit Aktut","ocirc":"Kleinbuchstabe o mit Zirkumflex","otilde":"Kleinbuchstabe o mit Tilde","ouml":"Kleinbuchstabe o mit Gravis","divide":"Divisionszeichen","oslash":"Kleines o mit Schrägstrich\nKleiner dänisch-norwegischer Umlaut ö","ugrave":"Kleinbuchstabe u mit Gravis","uacute":"Kleinbuchstabe u mit Aktut","ucirc":"Kleinbuchstabe u mit Zirkumflex","uuml":"Kleinbuchstabe u mit Trema","yacute":"Kleinbuchstabe y mit Aktut","thorn":"Kleines thorn","yuml":"Kleinbuchstabe y mit Trema","fnof":"Kleines f mit Haken\nFunction\nFlorin","Alpha":"Griechischer Großbuchstabe Alpha","Beta":"Griechischer Großbuchstabe Beta","Gamma":"Griechischer Großbuchstabe Gamma","Delta":"Griechischer Großbuchstabe Delta","Epsilon":"Griechischer Großbuchstabe Epsilon","Zeta":"Griechischer Großbuchstabe Zeta","Eta":"Griechischer Großbuchstabe Eta","Theta":"Griechischer Großbuchstabe Theta","Iota":"Griechischer Großbuchstabe Iota","Kappa":"Griechischer Großbuchstabe Kappa","Lambda":"Griechischer Großbuchstabe Lambda","Mu":"Griechischer Großbuchstabe My","Nu":"Griechischer Großbuchstabe Ny","Xi":"Griechischer Großbuchstabe Xi","Omicron":"Griechischer Großbuchstabe Omicron","Pi":"Griechischer Großbuchstabe Pi","Rho":"Griechischer Großbuchstabe Rho","Sigma":"Griechischer Großbuchstabe Sigma","Tau":"Griechischer Großbuchstabe Tau","Upsilon":"Griechischer Großbuchstabe Upsilon","Phi":"Griechischer Großbuchstabe Phi","Chi":"Griechischer Großbuchstabe Chi","Psi":"Griechischer Großbuchstabe Psi","Omega":"Griechischer Großbuchstabe Omega","alpha":"Griechischer Kleinbuchstabe Alpha","beta":"Griechischer Kleinbuchstabe Beta","gamma":"Griechischer Kleinbuchstabe Gamma","delta":"Griechischer Kleinbuchstabe Delta","epsilon":"Griechischer Kleinbuchstabe Epsilon","zeta":"Griechischer Kleinbuchstabe Zeta","eta":"Griechischer Kleinbuchstabe Eta","theta":"Griechischer Kleinbuchstabe Theta","iota":"Griechischer Kleinbuchstabe Iota","kappa":"Griechischer Kleinbuchstabe Kappa","lambda":"Griechischer Kleinbuchstabe Lambda","mu":"Griechischer Kleinbuchstabe My","nu":"Griechischer Kleinbuchstabe Ny","xi":"Griechischer Kleinbuchstabe Xi","omicron":"Griechischer Kleinbuchstabe Omicron","pi":"Griechischer Kleinbuchstabe Pi","rho":"Griechischer Kleinbuchstabe Rho","sigmaf":"Griechischer Kleinbuchstabe Sigma am Wortende","sigma":"Griechischer Kleinbuchstabe Sigma","tau":"Griechischer Kleinbuchstabe Tau","upsilon":"Griechischer Kleinbuchstabe Upsilon","phi":"Griechischer Kleinbuchstabe Phi","chi":"Griechischer Kleinbuchstabe Chi","psi":"Griechischer Kleinbuchstabe Psi","omega":"Griechischer Kleinbuchstabe Omega","thetasym":"Griechischer Kleinbuchstabe Theta (Symbol)","upsih":"Griechisches Upsilon mit Haken","piv":"Griechisches Pi-Symbol","bull":"Rundes Aufzählungszeichen\nSchwarzer kleiner Kreis","hellip":"Auslassung\nDrei kleine Punkte","prime":"Prime\nMinuten\nFuß","Prime":"Doppelstrich\nSekunden\nZoll","oline":"Überstrich\nÜberstreichungszeichen","frasl":"Schrägstrich für Bruch","weierp":"Kleines p in Schreibschrift\nPotenz\nWeierstraß-p","image":"Großes I in Frakturschrift\nImaginärteil","real":"Großes R in Frakturschrift\nRealteilsymbol","trade":"Markenzeichen","alefsym":"Aleph-Symbol\nErste transfinite Kardinalzahl","larr":"Linkspfeil","uarr":"Aufwärtspfeil","rarr":"Rechtspfeil","darr":"Abwärtspfeil","harr":"Links-Rechts-Pfeil","crarr":"Abwärtspfeil, der nach links abknickt\nZeilenumbruch","lArr":"Doppelter Linkspfeil","uArr":"Doppelter Aufwärtspfeil","rArr":"Doppelter Rechtspfeil","dArr":"Doppelter Abwärtspfeil","hArr":"Doppelter Rechts-Links-Pfeil","forall":"Für alle","part":"Partielle Differenzialgleichung","exist":"Es existiert","empty":"Leere Menge\nNullmenge\nDurchmesser","nabla":"Nabla\nRückwärtsdifferenz","isin":"Element von","notin":"Kein Element von","ni":"Enthält als Member","prod":"Unäres Produkt\nProduktzeichen","sum":"Unäre Summation","minus":"Minuszeichen","lowast":"Sternoperator","radic":"Quadratwurzel\nWurzelzeichen","prop":"proportional zu","infin":"Unendlich","ang":"Winkel","and":"Logisches UND\nHatschek","or":"Logisches ODER\nV","cap":"Schnittmenge\nBogen mit Öffnung oben","cup":"Vereinigungsmenge\nBogen mit Öffnung unten","int":"Integral","there4":"Deshalb","sim":"Tildenoperator\nVariiert mit\nÄhnlich wie","cong":"Etwa gleich mit","asymp":"Ungefähr gleich mit\nAsymptotisch","ne":"Nicht gleich mit","equiv":"Identisch mit","le":"Kleiner-gleich","ge":"Größer-gleich","sub":"Teil von","sup":"Obermenge von","nsub":"Kein Teil von","sube":"Teilmenge oder gleich mit","supe":"Obermenge oder gleich mit","oplus":"In Kreis eingeschlossenes Pluszeichen\nDirekte Summe","otimes":"In Kreis eingeschlossenes X\nVektorprodukt","perp":"Senkrecht\nOrthogonal zu\nPerpendikulär","sdot":"Punktoperator","lceil":"Linke Ecke oben\nSenkrechter Winkel mit Ecke links oben","rceil":"Rechte Ecke oben","lfloor":"Linke Ecke unten\nSenkrechter Winkel mit Ecke links unten","rfloor":"Rechte Ecke unten","lang":"Linke spitze Klammer","rang":"Rechte spitze Klammer","loz":"Raute","spades":"Schwarzes Pik (Kartenspiel)","clubs":"Schwarzes Kreuz (Kartenspiel)\nKleeblatt","hearts":"Schwarzes Herz (Kartenspiel)\nValentine","diams":"Schwarzes Karo (Kartenspiel)","OElig":"Ligatur aus Großbuchstaben O und E","oelig":"Ligatur aus Kleinbuchstaben o und e","Scaron":"Großbuchstabe S mit Caron","scaron":"Kleinbuchstabe s mit Caron","Yuml":"Großbuchstabe Y mit Trema","circ":"Zirkumflex, Akzent","tilde":"kleine Tilde","ensp":"Leerschritt von der Breite des Buchstaben n","emsp":"Leerschritt von der Breite des Buchstaben m","thinsp":"Schmaler Leerschritt","zwnj":"Nichtverbinder mit Nullbreite","zwj":"Verbinder mit Nullbreite","lrm":"Links-Rechts-Markierung","rlm":"Rechts-Links-Markierung","ndash":"Gedankenstrich von der Länge des Buchstabens n","mdash":"Gedankenstrich von der Länge des Buchstabens m","lsquo":"Linkes einfaches Anführungszeichen","rsquo":"Rechtes einfaches Anführungszeichen","sbquo":"Einfaches, gekrümmtes Anführungszeichen unten","ldquo":"Linkes doppeltes Anführungszeichen","rdquo":"Rechtes doppeltes Anführungszeichen","bdquo":"Doppeltes, gekrümmtes Anführungszeichen unten","dagger":"Kreuzzeichen","Dagger":"Doppelkreuzzeichen","permil":"Promillezeichen","lsaquo":"Einfaches linkes Anführungszeichen","rsaquo":"Einfaches rechtes Anführungszeichen","euro":"Euro-Zeichen","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"Symbol einfügen","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"Alice-blau","antiquewhite":"Antikweiß","aqua":"Wasserblau","aquamarine":"Aquamarin","azure":"Azur","beige":"Beige","bisque":"Bisquit","black":"Schwarz","blanchedalmond":"Mandelweiß","blue":"Blau","blueviolet":"Blauviolett","brown":"Braun","burlywood":"Burlywood","cadetblue":"Kadettenblau","chartreuse":"Helles Gelbgrün","chocolate":"Schokoladenbraun","coral":"Koralle","cornflowerblue":"Kornblumenblau","cornsilk":"Kornseide","crimson":"Karmesinrot","cyan":"Zyan","darkblue":"Dunkelblau","darkcyan":"Dunkelzyan","darkgoldenrod":"Dunkelgoldgelb","darkgray":"Dunkelgrau","darkgreen":"Dunkelgrün","darkgrey":"Dunkelgrau","darkkhaki":"Dunkelkhaki","darkmagenta":"Dunkelmagenta","darkolivegreen":"Dunkelolivgrün","darkorange":"Dunkelorange","darkorchid":"Dunkelorchidee","darkred":"Dunkelrot","darksalmon":"Dunkellachs","darkseagreen":"Dunkles Meergrün","darkslateblue":"Dunkelschieferblau","darkslategray":"Dunkelschiefergrau","darkslategrey":"Dunkelschiefergrau","darkturquoise":"Dunkeltürkis","darkviolet":"Dunkelviolett","deeppink":"Tiefrosa","deepskyblue":"Dunkles Himmelblau","dimgray":"Blassgrau","dimgrey":"Blassgrau","dodgerblue":"Dodger-blau","firebrick":"Schamottestein","floralwhite":"Blütenweiß","forestgreen":"Forstgrün","fuchsia":"Fuchsia","gainsboro":"Gainsboro","ghostwhite":"Geisterweiß","gold":"Gold","goldenrod":"Goldgelb","gray":"Grau","green":"Grün","greenyellow":"Grüngelb","grey":"Grau","honeydew":"Honigtau","hotpink":"Knallrosa","indianred":"Indischrot","indigo":"Indigoblau","ivory":"Elfenbein","khaki":"Khaki","lavender":"Lavendelblau","lavenderblush":"Lavendelhauch","lawngreen":"Grasgrün","lemonchiffon":"Zitronenchiffon","lightblue":"Hellblau","lightcoral":"Hellkoralle","lightcyan":"Hellzyan","lightgoldenrodyellow":"Hellgoldgelb","lightgray":"Hellgrau","lightgreen":"Hellgrün","lightgrey":"Hellgrau","lightpink":"Hellrosa","lightsalmon":"Helllachs","lightseagreen":"Helles Meergrün","lightskyblue":"Helles Himmelblau","lightslategray":"Helles Schiefergrau","lightslategrey":"Helles Schiefergrau","lightsteelblue":"Helles Stahlblau","lightyellow":"Hellgelb","lime":"Limone","limegreen":"Limonengrün","linen":"Leinen","magenta":"Magenta","maroon":"Kastanienbraun","mediumaquamarine":"Mittelaquamarin","mediumblue":"Mittelblau","mediumorchid":"Mittelorchidee","mediumpurple":"Mittelpurpur","mediumseagreen":"Mittelmeeresgrün","mediumslateblue":"Mittelschieferblau ","mediumspringgreen":"Mittelfrühlingsgrün","mediumturquoise":"Mitteltürkis ","mediumvioletred":"Mittelviolettrot ","midnightblue":"Mitternachtblau","mintcream":"Mintcreme","mistyrose":"Blassrose","moccasin":"Mokassin","navajowhite":"Navajo-weiß","navy":"Marineblau","oldlace":"Alte Spitze","olive":"Oliv","olivedrab":"Olivgrau","orange":"Orange","orangered":"Orangerot","orchid":"Orchidee","palegoldenrod":"Blassgoldgelb","palegreen":"Blassgrün","paleturquoise":"Blasstürkis","palevioletred":"Blassviolettrot ","papayawhip":"Papayacreme","peachpuff":"Pfirsich","peru":"Peru","pink":"Rosa","plum":"Pflaume","powderblue":"Pulverblau","purple":"Purpurrot","red":"Rot","rosybrown":"Rosigbraun","royalblue":"Königsblau","saddlebrown":"Sattelbraun","salmon":"Lachs","sandybrown":"Sandbraun","seagreen":"Meeresgrün","seashell":"Muschelweiß","sienna":"Sienna","silver":"Silbergrau","skyblue":"Himmelblau","slateblue":"Schieferblau","slategray":"Schiefergrau","slategrey":"Schiefergrau","snow":"Schneeweiß","springgreen":"Frühlingsgrün","steelblue":"Stahlblau","tan":"Hautfarben","teal":"Smaragdgrün","thistle":"Distel","tomato":"Tomatenrot","transparent":"Transparent","turquoise":"Türkis","violet":"Violett","wheat":"Weizen","white":"Weiß","whitesmoke":"Rauchweiß","yellow":"Gelb","yellowgreen":"Gelbgrün","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"r","greenLabel":"g","blueLabel":"b","hueLabel":"h","saturationLabel":"s","valueLabel":"v","degLabel":"°","hexLabel":"hex","huePickerTitle":"Farbtonauswahl","saturationPickerTitle":"Sättigungsauswahl","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"Tabelle einfügen","modifyTableTitle":"Tabelle ändern","rows":"Zeilen:","columns":"Spalten:","align":"Ausrichten:","cellPadding":"Zellenrandbreite:","cellSpacing":"Zellenabstand:","tableWidth":"Tabellenbreite:","backgroundColor":"Hintergrundfarbe:","borderColor":"Randfarbe:","borderThickness":"Umrandungsstärke:","percent":"Prozent","pixels":"Pixel","default":"Standard","left":"Links","center":"Mitte","right":"Rechts","buttonSet":"Festlegen","buttonInsert":"Einfügen","buttonCancel":"Abbrechen","selectTableLabel":"Tabelle auswählen","insertTableRowBeforeLabel":"Zeile oberhalb einfügen","insertTableRowAfterLabel":"Zeile unterhalb einfügen","insertTableColumnBeforeLabel":"Spalte oberhalb einfügen","insertTableColumnAfterLabel":"Spalte unterhalb einfügen","deleteTableRowLabel":"Zeile löschen","deleteTableColumnLabel":"Spalte löschen","colorTableCellTitle":"Hintergrundfarbe für Tabellenzelle","tableContextMenuTitle":"Kontextmenü für Tabelle","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"Aus Word einfügen","instructions":"Fügt den Inhalt aus Word in das Textfeld unten ein. Wenn Sie mit dem einzufügenden Inhalt zufrieden sind, klicken Sie auf die Schaltfläche zum Einfügen. Um das Einfügen von Text abzubrechen, klicken Sie auf die Schaltfläche zum Abbrechen. ","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"Anker einfügen","title":"Eigenschaften des Ankers","anchor":"Name:","text":"Beschreibung:","set":"Festlegen","cancel":"Abbrechen","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"Blockzitat","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"Grafik einfügen","url":"Grafik","browse":"Durchsuchen...","text":"Beschreibung","set":"Einfügen","invalidMessage":"Ungültiger Grafikdateityp","prePopuTextUrl":"Geben Sie eine gültige Grafik-URL ein","prePopuTextBrowse":"oder blättern Sie zu einer lokalen Datei.","_localized":{}}
});